summaryrefslogtreecommitdiff
path: root/libs/ardour/ardour/tempo.h
diff options
context:
space:
mode:
Diffstat (limited to 'libs/ardour/ardour/tempo.h')
-rw-r--r--libs/ardour/ardour/tempo.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libs/ardour/ardour/tempo.h b/libs/ardour/ardour/tempo.h
index 1b587a5668..d52232e88e 100644
--- a/libs/ardour/ardour/tempo.h
+++ b/libs/ardour/ardour/tempo.h
@@ -50,14 +50,14 @@ class TempoMap;
class LIBARDOUR_API Tempo {
public:
/**
* @param bpm Beats Per Minute
* @param type Note Type (default `4': quarter note)
*/
- Tempo (double bpm, double type=4.0) // defaulting to quarter note
- : _beats_per_minute (bpm), _note_type(type) {}
+ Tempo (double npm, double type=4.0) // defaulting to quarter note
+ : _beats_per_minute (npm), _note_type(type) {}
/*
- quarter note beats as distinct from a beat derived from meter and pulse.
+ note types per minute.
*/
double beats_per_minute () const { return _beats_per_minute; }
void set_beats_per_minute (double bpm) { _beats_per_minute = bpm; }
@@ -50,14 +50,14 @@ class TempoMap;
public:
/**
- * @param bpm Beats Per Minute
+ * @param npm Note Types per minute
* @param type Note Type (default `4': quarter note)
*/